pub struct RecordingManager { /* private fields */ }Expand description
Recording Manager — manages active recording sessions
Implementations
Sourceimpl RecordingManager
impl RecordingManager
pub fn store(&self) -> Arc<MaskStore>
Sourcepub fn start(&self, session_id: [u8; 16], service: String, admin_key_id: String)
pub fn start(&self, session_id: [u8; 16], service: String, admin_key_id: String)
Start recording for a session
Sourcepub fn record_packet(&self, session_id: [u8; 16], meta: PacketMetadata)
pub fn record_packet(&self, session_id: [u8; 16], meta: PacketMetadata)
Record a packet’s metadata into the active session
Sourcepub fn stop(&self, session_id: [u8; 16]) -> RecordingStopOutcome
pub fn stop(&self, session_id: [u8; 16]) -> RecordingStopOutcome
Stop recording and return the captured session if it has enough data.
pub fn stop_for_session_end(&self, session_id: [u8; 16]) -> RecordingStopOutcome
pub fn take_ready_or_stale( &self, idle_timeout_secs: u64, ) -> Vec<RecordingStopOutcome>
Sourcepub fn is_recording(&self, session_id: &[u8; 16]) -> bool
pub fn is_recording(&self, session_id: &[u8; 16]) -> bool
Check if a session is currently being recorded (O(1))
Sourcepub fn status(&self, session_id: &[u8; 16]) -> Option<RecordingStatus>
pub fn status(&self, session_id: &[u8; 16]) -> Option<RecordingStatus>
Get status of a recording session
Sourcepub fn active_sessions(&self) -> Vec<[u8; 16]>
pub fn active_sessions(&self) -> Vec<[u8; 16]>
Get all active recording session IDs